aboutsummaryrefslogtreecommitdiff
path: root/engines/scumm/boxes.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/scumm/boxes.cpp')
-rw-r--r--engines/scumm/boxes.cpp16
1 files changed, 7 insertions, 9 deletions
diff --git a/engines/scumm/boxes.cpp b/engines/scumm/boxes.cpp
index 15d5f04ed5..64d4d7422c 100644
--- a/engines/scumm/boxes.cpp
+++ b/engines/scumm/boxes.cpp
@@ -18,14 +18,12 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "scumm/scumm.h"
#include "scumm/actor.h"
#include "scumm/boxes.h"
+#include "scumm/resource.h"
#include "scumm/scumm_v0.h"
#include "scumm/scumm_v6.h"
#include "scumm/util.h"
@@ -728,7 +726,7 @@ int ScummEngine::getNextBox(byte from, byte to) {
dest = to;
do {
dest = itineraryMatrix[numOfBoxes * from + dest];
- } while (dest != Actor::kInvalidBox && !areBoxesNeighbours(from, dest));
+ } while (dest != Actor::kInvalidBox && !areBoxesNeighbors(from, dest));
if (dest == Actor::kInvalidBox)
dest = -1;
@@ -964,7 +962,7 @@ void ScummEngine::calcItineraryMatrix(byte *itineraryMatrix, int num) {
// Allocate the adjacent & itinerary matrices
adjacentMatrix = (byte *)malloc(boxSize * boxSize);
- // Initialise the adjacent matrix: each box has distance 0 to itself,
+ // Initialize the adjacent matrix: each box has distance 0 to itself,
// and distance 1 to its direct neighbors. Initially, it has distance
// 255 (= infinity) to all other boxes.
for (i = 0; i < num; i++) {
@@ -972,7 +970,7 @@ void ScummEngine::calcItineraryMatrix(byte *itineraryMatrix, int num) {
if (i == j) {
adjacentMatrix[i * boxSize + j] = 0;
itineraryMatrix[i * boxSize + j] = j;
- } else if (areBoxesNeighbours(i, j)) {
+ } else if (areBoxesNeighbors(i, j)) {
adjacentMatrix[i * boxSize + j] = 1;
itineraryMatrix[i * boxSize + j] = j;
} else {
@@ -1062,8 +1060,8 @@ void ScummEngine::createBoxMatrix() {
free(itineraryMatrix);
}
-/** Check if two boxes are neighbours. */
-bool ScummEngine::areBoxesNeighbours(int box1nr, int box2nr) {
+/** Check if two boxes are neighbors. */
+bool ScummEngine::areBoxesNeighbors(int box1nr, int box2nr) {
Common::Point tmp;
BoxCoords box;
BoxCoords box2;
@@ -1160,7 +1158,7 @@ bool ScummEngine::areBoxesNeighbours(int box1nr, int box2nr) {
return false;
}
-bool ScummEngine_v0::areBoxesNeighbours(int box1nr, int box2nr) {
+bool ScummEngine_v0::areBoxesNeighbors(int box1nr, int box2nr) {
int i;
const int numOfBoxes = getNumBoxes();
const byte *boxm;